==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/level/block/StyphiumBlock.java <==
package net.invictusslayer.slayersbeasts.world.level.block;

import net.invictusslayer.slayersbeasts.registries.SBBlocks;
import net.invictusslayer.slayersbeasts.world.level.gen.feature.SBConfiguredFeatures;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2256;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2398;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3558;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import net.minecraft.class_7924;

public class StyphiumBlock extends class_2248 implements class_2256 {
	public StyphiumBlock(class_2251 properties) {
		super(properties);
	}

	public void method_9514(class_2680 state, class_3218 level, class_2338 pos, class_5819 random) {
		if (!canBeStyphium(state, level, pos)) {
			boolean isDeepslate = state.method_27852(SBBlocks.DEEPSLATE_STYPHIUM.get());
			level.method_8501(pos, isDeepslate ? class_2246.field_28888.method_9564() : class_2246.field_10340.method_9564());
		}
	}

	private static boolean canBeStyphium(class_2680 state, class_4538 level, class_2338 pos) {
		class_2338 above = pos.method_10084();
		class_2680 stateAbove = level.method_8320(above);
		int i = class_3558.method_20049(level, state, pos, stateAbove, above, class_2350.field_11036, stateAbove.method_26193(level, above));
		return i < level.method_8315();
	}

	public boolean method_9651(class_4538 level, class_2338 pos, class_2680 state) {
		return level.method_8320(pos.method_10084()).method_26215();
	}

	public boolean method_9650(class_1937 level, class_5819 random, class_2338 pos, class_2680 state) {
		return true;
	}

	public void method_9652(class_3218 level, class_5819 random, class_2338 pos, class_2680 state) {
		level.method_30349().method_33310(class_7924.field_41239).flatMap(configured ->
				configured.method_40264(SBConfiguredFeatures.STYPHIUM_PATCH_BONEMEAL)).ifPresent(holder ->
				holder.comp_349().method_12862(level, level.method_14178().method_12129(), random, pos.method_10084()));
	}

	public void method_9496(class_2680 state, class_1937 level, class_2338 pos, class_5819 random) {
		if (random.method_43048(10) == 0) {
			level.method_8406(class_2398.field_11219, (double) pos.method_10263() + random.method_43058(), (double) pos.method_10264() + 1.1D, (double)pos.method_10260() + random.method_43058(), 0.0D, 0.0D, 0.0D);
		}
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/level/block/StyphiumBlock.java <==
package net.invictusslayer.slayersbeasts.world.level.block;

import net.invictusslayer.slayersbeasts.registries.SBBlocks;
import net.invictusslayer.slayersbeasts.world.level.gen.feature.SBConfiguredFeatures;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2256;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2398;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3558;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import net.minecraft.class_7924;

public class StyphiumBlock extends class_2248 implements class_2256 {
	public StyphiumBlock(class_2251 properties) {
		super(properties);
	}

	public void method_9514(class_2680 state, class_3218 level, class_2338 pos, class_5819 random) {
		if (!canBeStyphium(state, level, pos)) {
			boolean isDeepslate = state.method_27852(SBBlocks.DEEPSLATE_STYPHIUM.get());
			level.method_8501(pos, isDeepslate ? class_2246.field_28888.method_9564() : class_2246.field_10340.method_9564());
		}
	}

	private static boolean canBeStyphium(class_2680 state, class_4538 level, class_2338 pos) {
		class_2338 above = pos.method_10084();
		class_2680 stateAbove = level.method_8320(above);
		int i = class_3558.method_20049(state, stateAbove, class_2350.field_11036, stateAbove.method_26193());
		return i < 15;
	}

	public boolean method_9651(class_4538 level, class_2338 pos, class_2680 state) {
		return level.method_8320(pos.method_10084()).method_26215();
	}

	public boolean method_9650(class_1937 level, class_5819 random, class_2338 pos, class_2680 state) {
		return true;
	}

	public void method_9652(class_3218 level, class_5819 random, class_2338 pos, class_2680 state) {
		level.method_30349().method_58561(class_7924.field_41239).flatMap(configured ->
				configured.comp_349().method_46746(SBConfiguredFeatures.STYPHIUM_PATCH_BONEMEAL)).ifPresent(holder ->
				holder.comp_349().method_12862(level, level.method_14178().method_12129(), random, pos.method_10084()));
	}

	public void method_9496(class_2680 state, class_1937 level, class_2338 pos, class_5819 random) {
		if (random.method_43048(10) == 0) {
			level.method_8406(class_2398.field_11219, (double) pos.method_10263() + random.method_43058(), (double) pos.method_10264() + 1.1D, (double)pos.method_10260() + random.method_43058(), 0.0D, 0.0D, 0.0D);
		}
	}
}
